@@ -65,35 +65,50 @@ class Parser
             $mount = preg_split("/\n/", $mount, -1, PREG_SPLIT_NO_EMPTY);
             foreach ($mount as $mount_line) {
                 if (preg_match("/(\S+) on ([\S ]+) type (.*) \((.*)\)/", $mount_line, $mount_buf)) {
-                    $mount_parm[$mount_buf[2]]['fstype'] = $mount_buf[3];
-                    $mount_parm[$mount_buf[2]]['name'] = $mount_buf[1];
-                    if (PSI_SHOW_MOUNT_OPTION) $mount_parm[$mount_buf[2]]['options'] = $mount_buf[4];
+                    $parm = array();
+                    $parm['mountpoint'] = trim($mount_buf[2]);
+                    $parm['fstype'] = $mount_buf[3];
+                    $parm['name'] = $mount_buf[1];
+                    if (PSI_SHOW_MOUNT_OPTION) $parm['options'] = $mount_buf[4];
+                    $mount_parm[] = $parm;
                 } elseif (preg_match("/(\S+) is (.*) mounted on (\S+) \(type (.*)\)/", $mount_line, $mount_buf)) {
-                    $mount_parm[$mount_buf[3]]['fstype'] = $mount_buf[4];
-                    $mount_parm[$mount_buf[3]]['name'] = $mount_buf[1];
-                    if (PSI_SHOW_MOUNT_OPTION) $mount_parm[$mount_buf[3]]['options'] = $mount_buf[2];
+                    $parm = array();
+                    $parm['mountpoint'] = trim($mount_buf[3]);
+                    $parm['fstype'] = $mount_buf[4];
+                    $parm['name'] = $mount_buf[1];
+                    if (PSI_SHOW_MOUNT_OPTION) $parm['options'] = $mount_buf[2];
+                    $mount_parm[] = $parm;
                 } elseif (preg_match("/(\S+) (.*) on (\S+) \((.*)\)/", $mount_line, $mount_buf)) {
-                    $mount_parm[$mount_buf[3]]['fstype'] = $mount_buf[2];
-                    $mount_parm[$mount_buf[3]]['name'] = $mount_buf[1];
-                    if (PSI_SHOW_MOUNT_OPTION) $mount_parm[$mount_buf[3]]['options'] = $mount_buf[4];
+                    $parm = array();
+                    $parm['mountpoint'] = trim($mount_buf[3]);
+                    $parm['fstype'] = $mount_buf[2];
+                    $parm['name'] = $mount_buf[1];
+                    if (PSI_SHOW_MOUNT_OPTION) $parm['options'] = $mount_buf[4];
+                    $mount_parm[] = $parm;
                 } elseif (preg_match("/(\S+) on ([\S ]+) \((\S+)(,\s(.*))?\)/", $mount_line, $mount_buf)) {
-                    $mount_parm[$mount_buf[2]]['fstype'] = $mount_buf[3];
-                    $mount_parm[$mount_buf[2]]['name'] = $mount_buf[1];
-                    if (PSI_SHOW_MOUNT_OPTION) $mount_parm[$mount_buf[2]]['options'] = isset($mount_buf[5]) ? $mount_buf[5] : '';
+                    $parm = array();
+                    $parm['mountpoint'] = trim($mount_buf[2]);
+                    $parm['fstype'] = $mount_buf[3];
+                    $parm['name'] = $mount_buf[1];
+                    if (PSI_SHOW_MOUNT_OPTION) $parm['options'] = isset($mount_buf[5]) ? $mount_buf[5] : '';
+                    $mount_parm[] = $parm;
                 }
             }
         } elseif (CommonFunctions::rfts("/etc/mtab", $mount)) {
             $mount = preg_split("/\n/", $mount, -1, PREG_SPLIT_NO_EMPTY);
             foreach ($mount as $mount_line) {
                 if (preg_match("/(\S+) (\S+) (\S+) (\S+) ([0-9]+) ([0-9]+)/", $mount_line, $mount_buf)) {
+                    $parm = array();
                     $mount_point = preg_replace("/\\\\040/i", ' ', $mount_buf[2]); //space as \040
-                    $mount_parm[$mount_point]['fstype'] = $mount_buf[3];
-                    $mount_parm[$mount_point]['name'] = $mount_buf[1];
-                    if (PSI_SHOW_MOUNT_OPTION) $mount_parm[$mount_point]['options'] = $mount_buf[4];
+                    $parm['mountpoint'] = $mount_point;
+                    $parm['fstype'] = $mount_buf[3];
+                    $parm['name'] = $mount_buf[1];
+                    if (PSI_SHOW_MOUNT_OPTION) $parm['options'] = $mount_buf[4];
+                    $mount_parm[] = $parm;
                 }
             }
         }
-        if (CommonFunctions::executeProgram('df', '-k '.$df_param, $df, PSI_DEBUG)) {
+        if (CommonFunctions::executeProgram('df', '-k '.$df_param, $df, PSI_DEBUG) && ($df!=="")) {
             $df = preg_split("/\n/", $df, -1, PREG_SPLIT_NO_EMPTY);
             if (PSI_SHOW_INODES) {
                 if (CommonFunctions::executeProgram('df', '-i '.$df_param, $df2, PSI_DEBUG)) {
@@ -133,30 +148,70 @@ class Parser
                         }
                         if (PSI_SHOW_MOUNT_POINT) $dev->setMountPoint($df_buf[5]);
 
-                        if (isset($mount_parm[$df_buf[5]])) {
-                            $dev->setFsType($mount_parm[$df_buf[5]]['fstype']);
-                            if (PSI_SHOW_MOUNT_OPTION) {
-                                if (PSI_SHOW_MOUNT_CREDENTIALS) {
-                                    $dev->setOptions($mount_parm[$df_buf[5]]['options']);
-                                } else {
-                                    $mpo=$mount_parm[$df_buf[5]]['options'];
+                        $notwas = true;
+                        if (isset($mount_parm)) {
+                            foreach ($mount_parm as $mount_param) { //name and mountpoint find
+                                if (($mount_param['name']===trim($df_buf[0])) && ($mount_param['mountpoint']===$df_buf[5])) {
+                                    $dev->setFsType($mount_param['fstype']);
+                                    if (PSI_SHOW_MOUNT_OPTION) {
+                                        if (PSI_SHOW_MOUNT_CREDENTIALS) {
+                                            $dev->setOptions($mount_param['options']);
+                                        } else {
+                                            $mpo=$mount_param['options'];
 
-                                    $mpo=preg_replace('/(^guest,)|(^guest$)|(,guest$)/i', '', $mpo);
-                                    $mpo=preg_replace('/,guest,/i', ',', $mpo);
+                                            $mpo=preg_replace('/(^guest,)|(^guest$)|(,guest$)/i', '', $mpo);
+                                            $mpo=preg_replace('/,guest,/i', ',', $mpo);
 
-                                    $mpo=preg_replace('/(^user=[^,]*,)|(^user=[^,]*$)|(,user=[^,]*$)/i', '', $mpo);
-                                    $mpo=preg_replace('/,user=[^,]*,/i', ',', $mpo);
+                                            $mpo=preg_replace('/(^user=[^,]*,)|(^user=[^,]*$)|(,user=[^,]*$)/i', '', $mpo);
+                                            $mpo=preg_replace('/,user=[^,]*,/i', ',', $mpo);
 
-                                    $mpo=preg_replace('/(^username=[^,]*,)|(^username=[^,]*$)|(,username=[^,]*$)/i', '', $mpo);
-                                    $mpo=preg_replace('/,username=[^,]*,/i', ',', $mpo);
+                                            $mpo=preg_replace('/(^username=[^,]*,)|(^username=[^,]*$)|(,username=[^,]*$)/i', '', $mpo);
+                                            $mpo=preg_replace('/,username=[^,]*,/i', ',', $mpo);
 
-                                    $mpo=preg_replace('/(^password=[^,]*,)|(^password=[^,]*$)|(,password=[^,]*$)/i', '', $mpo);
-                                    $mpo=preg_replace('/,password=[^,]*,/i', ',', $mpo);
+                                            $mpo=preg_replace('/(^password=[^,]*,)|(^password=[^,]*$)|(,password=[^,]*$)/i', '', $mpo);
+                                            $mpo=preg_replace('/,password=[^,]*,/i', ',', $mpo);
 
-                                    $dev->setOptions($mpo);
+                                            $dev->setOptions($mpo);
+                                        }
+                                    }
+                                    $notwas = false;
+                                    break;
+                                }
+                            }
+                            if ($notwas) foreach ($mount_parm as $mount_param) { //mountpoint find
+                                if ($mount_param['mountpoint']===$df_buf[5]) {
+                                    $dev->setFsType($mount_param['fstype']);
+                                    if (PSI_SHOW_MOUNT_OPTION) {
+                                        if (PSI_SHOW_MOUNT_CREDENTIALS) {
+                                            $dev->setOptions($mount_param['options']);
+                                        } else {
+                                            $mpo=$mount_param['options'];
+
+                                            $mpo=preg_replace('/(^guest,)|(^guest$)|(,guest$)/i', '', $mpo);
+                                            $mpo=preg_replace('/,guest,/i', ',', $mpo);
+
+                                            $mpo=preg_replace('/(^user=[^,]*,)|(^user=[^,]*$)|(,user=[^,]*$)/i', '', $mpo);
+                                            $mpo=preg_replace('/,user=[^,]*,/i', ',', $mpo);
+
+                                            $mpo=preg_replace('/(^username=[^,]*,)|(^username=[^,]*$)|(,username=[^,]*$)/i', '', $mpo);
+                                            $mpo=preg_replace('/,username=[^,]*,/i', ',', $mpo);
+
+                                            $mpo=preg_replace('/(^password=[^,]*,)|(^password=[^,]*$)|(,password=[^,]*$)/i', '', $mpo);
+                                            $mpo=preg_replace('/,password=[^,]*,/i', ',', $mpo);
+
+                                            $dev->setOptions($mpo);
+                                        }
+                                    }
+                                    $notwas = false;
+                                    break;
                                 }
                             }
                         }
+
+                        if ($notwas) {
+                            $dev->setFsType('unknown');
+                        }
+
                         if (PSI_SHOW_INODES && isset($df_inodes[trim($df_buf[0])])) {
                             $dev->setPercentInodesUsed($df_inodes[trim($df_buf[0])]);
                         }
@@ -166,17 +221,17 @@ class Parser
             }
         } else {
             if (isset($mount_parm)) {
-                foreach ($mount_parm as $mount_point=>$mount_param) {
-                    $total = disk_total_space($mount_point);
+                foreach ($mount_parm as $mount_param) {
+                    $total = disk_total_space($mount_param['mountpoint']);
                     if (($mount_param['fstype'] != 'none') && ($total > 0)) {
                         $dev = new DiskDevice();
                         $dev->setName($mount_param['name']);
                         $dev->setFsType($mount_param['fstype']);
 
-                        if (PSI_SHOW_MOUNT_POINT) $dev->setMountPoint($mount_point);
+                        if (PSI_SHOW_MOUNT_POINT) $dev->setMountPoint($mount_param['mountpoint']);
 
                         $dev->setTotal($total);
-                        $free = disk_free_space($mount_point);
+                        $free = disk_free_space($mount_param['mountpoint']);
                         if ($free > 0) {
                             $dev->setFree($free);
                         } else {
