@@ -111,7 +111,7 @@ class JavaScriptPacker
     private function _pack($script)
     {
         for ($i = 0; isset($this->_parsers[$i]); $i++) {
-            $script = call_user_func(array(&$this,$this->_parsers[$i]), $script);
+            $script = call_user_func(array(&$this, $this->_parsers[$i]), $script);
         }
 
         return $script;
@@ -311,12 +311,12 @@ class JavaScriptPacker
         }
         // convert from a string to an array
         ksort($keywords['sorted']);
-        $keywords = "'" . implode('|',$keywords['sorted']) . "'.split('|')";
+        $keywords = "'" . implode('|', $keywords['sorted']) . "'.split('|')";
 
         $encode = ($this->_encoding > 62) ? '_encode95' : $this->_getEncoder($ascii);
         $encode = $this->_getJSFunction($encode);
-        $encode = preg_replace('/_encoding/','$ascii', $encode);
-        $encode = preg_replace('/arguments\\.callee/','$encode', $encode);
+        $encode = preg_replace('/_encoding/', '$ascii', $encode);
+        $encode = preg_replace('/arguments\\.callee/', '$encode', $encode);
         $inline = '\\$count' . ($ascii > 10 ? '.toString(\\$ascii)' : '');
 
         // $decode: code snippet to speed up decoding
@@ -757,8 +757,7 @@ class ParseMaster
             $regexp = '/'.'\\'.$escapeChar.'/';
             $this->buffer = array('escapeChar'=> $escapeChar, 'i' => 0);
 
-            return preg_replace_callback
-            (
+            return preg_replace_callback(
                 $regexp,
                 array(&$this, '_unescapeBis'),
                 $string
