@@ -39,42 +39,42 @@ abstract class BSDCommon extends OS
      *
      * @var string
      */
-    private $_CPURegExp1 = "";
+    private $_CPURegExp1 = "//";
 
     /**
      * regexp2 for cpu information out of the syslog
      *
      * @var string
      */
-    private $_CPURegExp2 = "";
+    private $_CPURegExp2 = "//";
 
     /**
      * regexp1 for scsi information out of the syslog
      *
      * @var string
      */
-    private $_SCSIRegExp1 = "";
+    private $_SCSIRegExp1 = "//";
 
     /**
      * regexp2 for scsi information out of the syslog
      *
      * @var string
      */
-    private $_SCSIRegExp2 = "";
+    private $_SCSIRegExp2 = "//";
 
     /**
      * regexp1 for pci information out of the syslog
      *
      * @var string
      */
-    private $_PCIRegExp1 = "";
+    private $_PCIRegExp1 = "//";
 
     /**
      * regexp1 for pci information out of the syslog
      *
      * @var string
      */
-    private $_PCIRegExp2 = "";
+    private $_PCIRegExp2 = "//";
 
     /**
      * call parent constructor
@@ -208,24 +208,6 @@ abstract class BSDCommon extends OS
         }
     }
 
-    /**
-     * IP of the Canonical Host Name
-     *
-     * @return void
-     */
-    protected function ip()
-    {
-        if (PSI_USE_VHOST === true) {
-            $this->sys->setIp(gethostbyname($this->sys->getHostname()));
-        } else {
-            if (!($result = getenv('SERVER_ADDR'))) {
-                $this->sys->setIp(gethostbyname($this->sys->getHostname()));
-            } else {
-                $this->sys->setIp($result);
-            }
-        }
-    }
-
     /**
      * Kernel Version
      *
@@ -235,18 +217,10 @@ abstract class BSDCommon extends OS
     {
         $s = $this->grabkey('kern.version');
         $a = preg_split('/:/', $s);
-        $this->sys->setKernel($a[0].$a[1].':'.$a[2]);
-    }
-
-    /**
-     * Number of Users
-     *
-     * @return void
-     */
-    protected function users()
-    {
-        if (CommonFunctions::executeProgram('who', '| wc -l', $buf, PSI_DEBUG)) {
-            $this->sys->setUsers($buf);
+        if (isset($a[2])) {
+            $this->sys->setKernel($a[0].$a[1].':'.$a[2]);
+        } else {
+            $this->sys->setKernel($s);
         }
     }
 
@@ -262,7 +236,7 @@ abstract class BSDCommon extends OS
         $s = preg_replace('/{ /', '', $s);
         $s = preg_replace('/ }/', '', $s);
         $this->sys->setLoad($s);
-        if (PSI_LOAD_BAR) {
+        if (PSI_LOAD_BAR && (PSI_OS != "Darwin")) {
             if ($fd = $this->grabkey('kern.cp_time')) {
                 // Find out the CPU load
                 // user + sys = load
@@ -289,31 +263,46 @@ abstract class BSDCommon extends OS
     protected function cpuinfo()
     {
         $dev = new CpuDevice();
-        $dev->setModel($this->grabkey('hw.model'));
+
+        if (PSI_OS == "NetBSD") {
+            if ($model = $this->grabkey('machdep.cpu_brand')) {
+               $dev->setModel($model);
+            }
+            if ($cpuspeed = $this->grabkey('machdep.tsc_freq')) {
+               $dev->setCpuSpeed(round($cpuspeed / 1000000));
+            }
+        }
+
+        if ($dev->getModel() === "") {
+            $dev->setModel($this->grabkey('hw.model'));
+        }
         $notwas = true;
         foreach ($this->readdmesg() as $line) {
             if ($notwas) {
-               if (preg_match("/".$this->_CPURegExp1."/", $line, $ar_buf)) {
-                    $dev->setCpuSpeed(round($ar_buf[2]));
+               if (preg_match($this->_CPURegExp1, $line, $ar_buf)) {
+                    if ($dev->getCpuSpeed() === 0) {
+                        $dev->setCpuSpeed(round($ar_buf[2]));
+                    }
                     $notwas = false;
                 }
             } else {
                 if (preg_match("/ Origin| Features/", $line, $ar_buf)) {
-                       if (preg_match("/ Features2[ ]*=.*<(.*)>/", $line, $ar_buf)) {
-                           $feats = preg_split("/,/", strtolower(trim($ar_buf[1])), -1, PREG_SPLIT_NO_EMPTY);
-                           foreach ($feats as $feat) {
-                                if (($feat=="vmx") || ($feat=="svm")) {
-                                   $dev->setVirt($feat);
-                                   break 2;
-                                }
-                           }
-                           break;
-                       }
+                    if (preg_match("/ Features2[ ]*=.*<(.*)>/", $line, $ar_buf)) {
+                        $feats = preg_split("/,/", strtolower(trim($ar_buf[1])), -1, PREG_SPLIT_NO_EMPTY);
+                        foreach ($feats as $feat) {
+                            if (($feat=="vmx") || ($feat=="svm")) {
+                                $dev->setVirt($feat);
+                                break 2;
+                            }
+                        }
+                        break;
+                    }
                 } else break;
             }
         }
+
         $ncpu = $this->grabkey('hw.ncpu');
-        if ( is_null($ncpu) || (trim($ncpu) == "") || (!($ncpu >= 1)) )
+        if (is_null($ncpu) || (trim($ncpu) == "") || (!($ncpu >= 1)))
             $ncpu = 1;
         for ($ncpu ; $ncpu > 0 ; $ncpu--) {
             $this->sys->setCpus($dev);
@@ -329,11 +318,11 @@ abstract class BSDCommon extends OS
     protected function scsi()
     {
         foreach ($this->readdmesg() as $line) {
-            if (preg_match("/".$this->_SCSIRegExp1."/", $line, $ar_buf)) {
+            if (preg_match($this->_SCSIRegExp1, $line, $ar_buf)) {
                 $dev = new HWDevice();
                 $dev->setName($ar_buf[1].": ".$ar_buf[2]);
                 $this->sys->setScsiDevices($dev);
-            } elseif (preg_match("/".$this->_SCSIRegExp2."/", $line, $ar_buf)) {
+            } elseif (preg_match($this->_SCSIRegExp2, $line, $ar_buf)) {
                 /* duplication security */
                 $notwas = true;
                 foreach ($this->sys->getScsiDevices() as $finddev) {
@@ -412,13 +401,13 @@ abstract class BSDCommon extends OS
      */
     protected function pci()
     {
-        if (!is_array($results = Parser::lspci(false)) || !is_array($results = $this->pciconf())) {
+        if ((!$results = Parser::lspci(false)) && (!$results = $this->pciconf())) {
             foreach ($this->readdmesg() as $line) {
-                if (preg_match("/".$this->_PCIRegExp1."/", $line, $ar_buf)) {
+                if (preg_match($this->_PCIRegExp1, $line, $ar_buf)) {
                     $dev = new HWDevice();
                     $dev->setName($ar_buf[1].": ".$ar_buf[2]);
                     $results[] = $dev;
-                } elseif (preg_match("/".$this->_PCIRegExp2."/", $line, $ar_buf)) {
+                } elseif (preg_match($this->_PCIRegExp2, $line, $ar_buf)) {
                     $dev = new HWDevice();
                     $dev->setName($ar_buf[1].": ".$ar_buf[2]);
                     $results[] = $dev;
@@ -539,7 +528,7 @@ abstract class BSDCommon extends OS
                     $this->sys->setUSBDevices($dev);
             }
         }
-     }
+    }
 
     /**
      * filesystem information
@@ -582,11 +571,10 @@ abstract class BSDCommon extends OS
         $this->cpuinfo();
         $this->filesystems();
         $this->kernel();
-        $this->users();
         $this->loadavg();
         $this->hostname();
-        $this->ip();
         $this->scsi();
         $this->usb();
+        $this->_users();
     }
 }
