@@ -25,6 +25,13 @@
  */
 class Webpage extends Output implements PSI_Interface_Output
 {
+    /**
+     * configured indexname
+     *
+     * @var String
+     */
+    private $_indexname;
+
     /**
      * configured language
      *
@@ -46,6 +53,20 @@ class Webpage extends Output implements PSI_Interface_Output
      */
     private $_templates = array();
 
+    /**
+     * configured bootstrap template
+     *
+     * @var String
+     */
+    private $_bootstrap_template;
+
+    /**
+     * all available bootstrap templates
+     *
+     * @var Array
+     */
+    private $_bootstrap_templates = array();
+
     /**
      * all available languages
      *
@@ -53,11 +74,26 @@ class Webpage extends Output implements PSI_Interface_Output
      */
     private $_languages = array();
 
+    /**
+     * configured show picklist language
+     *
+     * @var boolean
+     */
+    private $_pick_language;
+
+    /**
+     * configured show picklist template
+     *
+     * @var boolean
+     */
+    private $_pick_template;
+
     /**
      * check for all extensions that are needed, initialize needed vars and read phpsysinfo.ini
      */
-    public function __construct()
+    public function __construct($indexname="dynamic")
     {
+        $this->_indexname = $indexname;
         parent::__construct();
         $this->_getTemplateList();
         $this->_getLanguageList();
@@ -71,15 +107,18 @@ class Webpage extends Output implements PSI_Interface_Output
      */
     private function _checkTemplateLanguage()
     {
-        $this->_template = trim(strtolower(PSI_DEFAULT_TEMPLATE));
-        if (!file_exists(APP_ROOT.'/templates/'.$this->_template.".css")) {
+        if (!defined("PSI_DEFAULT_TEMPLATE") || (($this->_template = strtolower(trim(PSI_DEFAULT_TEMPLATE))) == "") || !file_exists(APP_ROOT.'/templates/'.$this->_template.".css")) {
             $this->_template = 'phpsysinfo';
         }
+        if (!defined("PSI_DEFAULT_BOOTSTRAP_TEMPLATE") || (($this->_bootstrap_template = strtolower(trim(PSI_DEFAULT_BOOTSTRAP_TEMPLATE))) == "") || !file_exists(APP_ROOT.'/templates/'.$this->_bootstrap_template.".css")) {
+            $this->_bootstrap_template = 'phpsysinfo';
+        }
+        $this->_pick_template = !defined("PSI_SHOW_PICKLIST_TEMPLATE") || (PSI_SHOW_PICKLIST_TEMPLATE !== false);
 
-        $this->_language = trim(strtolower(PSI_DEFAULT_LANG));
-        if (!file_exists(APP_ROOT.'/language/'.$this->_language.".xml")) {
+        if (!defined("PSI_DEFAULT_LANG") || (($this->_language = strtolower(trim(PSI_DEFAULT_LANG))) == "") || !file_exists(APP_ROOT.'/language/'.$this->_language.".xml")) {
             $this->_language = 'en';
         }
+        $this->_pick_language = !defined("PSI_SHOW_PICKLIST_LANG") || (PSI_SHOW_PICKLIST_LANG !== false);
     }
 
     /**
@@ -95,7 +134,11 @@ class Webpage extends Output implements PSI_Interface_Output
             $tpl_ext = substr($file, strlen($file) - 4);
             $tpl_name = substr($file, 0, strlen($file) - 4);
             if ($tpl_ext === ".css") {
-                array_push($this->_templates, $tpl_name);
+                if (preg_match("/(\S+)_bootstrap$/", $tpl_name, $ar_buf)) {
+                    array_push($this->_bootstrap_templates, $ar_buf[1]);
+                } else {
+                    array_push($this->_templates, $tpl_name);
+                }
             }
         }
     }
@@ -127,12 +170,20 @@ class Webpage extends Output implements PSI_Interface_Output
     {
         $this->_checkTemplateLanguage();
 
-        $tpl = new Template("/templates/html/index_dynamic.html");
+        $tpl = new Template("/templates/html/index_".$this->_indexname.".html");
 
         $tpl->set("template", $this->_template);
         $tpl->set("templates", $this->_templates);
+        $tpl->set("bootstraptemplate", $this->_bootstrap_template);
+        $tpl->set("bootstraptemplates", $this->_bootstrap_templates);
+        $tpl->set("picktemplate", $this->_pick_template);
         $tpl->set("language", $this->_language);
         $tpl->set("languages", $this->_languages);
+        $tpl->set("picklanguage", $this->_pick_language);
+        $tpl->set("showCPUListExpanded", defined('PSI_SHOW_CPULIST_EXPANDED') ? (PSI_SHOW_CPULIST_EXPANDED ? 'true' : 'false') : 'true');
+        $tpl->set("showCPUInfoExpanded", defined('PSI_SHOW_CPUINFO_EXPANDED') ? (PSI_SHOW_CPUINFO_EXPANDED ? 'true' : 'false') : 'false');
+        $tpl->set("showNetworkInfosExpanded", defined('PSI_SHOW_NETWORK_INFOS_EXPANDED') ? (PSI_SHOW_NETWORK_INFOS_EXPANDED ? 'true' : 'false') : 'false');
+        $tpl->set("showMemoryInfosExpanded", defined('PSI_SHOW_MEMORY_INFOS_EXPANDED') ? (PSI_SHOW_MEMORY_INFOS_EXPANDED ? 'true' : 'false') : 'false');
 
         echo $tpl->fetch();
     }
