@@ -92,7 +92,7 @@ class XML
      */
     public function __construct($complete = false, $pluginname = "")
     {
-        $this->_errors = Error::singleton();
+        $this->_errors = PSI_Error::singleton();
         if ($pluginname == "") {
             $this->_plugin_request = false;
             $this->_plugin = '';
@@ -200,7 +200,7 @@ class XML
                 $device->addAttribute('TxBytes', $dev->getTxBytes());
                 $device->addAttribute('Err', $dev->getErrors());
                 $device->addAttribute('Drops', $dev->getDrops());
-                if ( defined('PSI_SHOW_NETWORK_INFOS') && PSI_SHOW_NETWORK_INFOS && $dev->getInfo() )
+                if (defined('PSI_SHOW_NETWORK_INFOS') && PSI_SHOW_NETWORK_INFOS && $dev->getInfo())
                     $device->addAttribute('Info', $dev->getInfo());
             }
         }
@@ -218,20 +218,23 @@ class XML
         if ($this->_sys->getMachine() != "") {
             $hardware->addAttribute('Name', $this->_sys->getMachine());
         }
-        $pci = $hardware->addChild('PCI');
+        $pci = null;
         foreach (System::removeDupsAndCount($this->_sys->getPciDevices()) as $dev) {
+            if ($pci === null) $pci = $hardware->addChild('PCI');
             $tmp = $pci->addChild('Device');
             $tmp->addAttribute('Name', $dev->getName());
             $tmp->addAttribute('Count', $dev->getCount());
         }
-        $usb = $hardware->addChild('USB');
+        $usb = null;
         foreach (System::removeDupsAndCount($this->_sys->getUsbDevices()) as $dev) {
+            if ($usb === null) $usb = $hardware->addChild('USB');
             $tmp = $usb->addChild('Device');
             $tmp->addAttribute('Name', $dev->getName());
             $tmp->addAttribute('Count', $dev->getCount());
         }
-        $ide = $hardware->addChild('IDE');
+        $ide = null;
         foreach (System::removeDupsAndCount($this->_sys->getIdeDevices()) as $dev) {
+            if ($ide === null) $ide = $hardware->addChild('IDE');
             $tmp = $ide->addChild('Device');
             $tmp->addAttribute('Name', $dev->getName());
             $tmp->addAttribute('Count', $dev->getCount());
@@ -239,8 +242,9 @@ class XML
                 $tmp->addAttribute('Capacity', $dev->getCapacity());
             }
         }
-        $scsi = $hardware->addChild('SCSI');
+        $scsi = null;
         foreach (System::removeDupsAndCount($this->_sys->getScsiDevices()) as $dev) {
+            if ($scsi === null) $scsi = $hardware->addChild('SCSI');
             $tmp = $scsi->addChild('Device');
             $tmp->addAttribute('Name', $dev->getName());
             $tmp->addAttribute('Count', $dev->getCount());
@@ -248,9 +252,24 @@ class XML
                 $tmp->addAttribute('Capacity', $dev->getCapacity());
             }
         }
+        $tb = null;
+        foreach (System::removeDupsAndCount($this->_sys->getTbDevices()) as $dev) {
+            if ($tb === null) $tb = $hardware->addChild('TB');
+            $tmp = $tb->addChild('Device');
+            $tmp->addAttribute('Name', $dev->getName());
+            $tmp->addAttribute('Count', $dev->getCount());
+        }
+        $i2c = null;
+        foreach (System::removeDupsAndCount($this->_sys->getI2cDevices()) as $dev) {
+            if ($i2c === null) $i2c = $hardware->addChild('I2C');
+            $tmp = $i2c->addChild('Device');
+            $tmp->addAttribute('Name', $dev->getName());
+            $tmp->addAttribute('Count', $dev->getCount());
+        }
 
-        $cpu = $hardware->addChild('CPU');
+        $cpu = null;
         foreach ($this->_sys->getCpus() as $oneCpu) {
+            if ($cpu === null) $cpu = $hardware->addChild('CPU');
             $tmp = $cpu->addChild('CpuCore');
             $tmp->addAttribute('Model', $oneCpu->getModel());
             if ($oneCpu->getCpuSpeed() !== 0) {
@@ -336,7 +355,7 @@ class XML
     private function _fillDevice(SimpleXMLExtended $mount, DiskDevice $dev, $i)
     {
         $mount->addAttribute('MountPointID', $i);
-        $mount->addAttribute('FSType', $dev->getFsType());
+        if ($dev->getFsType()!=="") $mount->addAttribute('FSType', $dev->getFsType());
         $mount->addAttribute('Name', $dev->getName());
         $mount->addAttribute('Free', sprintf("%.0f", $dev->getFree()));
         $mount->addAttribute('Used', sprintf("%.0f", $dev->getUsed()));
@@ -344,7 +363,7 @@ class XML
         $mount->addAttribute('Percent', $dev->getPercentUsed());
         if (PSI_SHOW_MOUNT_OPTION === true) {
             if ($dev->getOptions() !== null) {
-                $mount->addAttribute('MountOptions', preg_replace("/,/",", ",$dev->getOptions()));
+                $mount->addAttribute('MountOptions', preg_replace("/,/", ", ", $dev->getOptions()));
             }
         }
         if ($dev->getPercentInodesUsed() !== null) {
@@ -364,14 +383,14 @@ class XML
     {
         $hideMounts = $hideFstypes = $hideDisks = array();
         $i = 1;
-        if ( defined('PSI_HIDE_MOUNTS') && is_string(PSI_HIDE_MOUNTS) ) {
+        if (defined('PSI_HIDE_MOUNTS') && is_string(PSI_HIDE_MOUNTS)) {
             if (preg_match(ARRAY_EXP, PSI_HIDE_MOUNTS)) {
                 $hideMounts = eval(PSI_HIDE_MOUNTS);
             } else {
                 $hideMounts = array(PSI_HIDE_MOUNTS);
             }
         }
-        if ( defined('PSI_HIDE_FS_TYPES') && is_string(PSI_HIDE_FS_TYPES) ) {
+        if (defined('PSI_HIDE_FS_TYPES') && is_string(PSI_HIDE_FS_TYPES)) {
             if (preg_match(ARRAY_EXP, PSI_HIDE_FS_TYPES)) {
                 $hideFstypes = eval(PSI_HIDE_FS_TYPES);
             } else {
@@ -423,7 +442,7 @@ class XML
                     if ($dev->getMax() !== null) {
                         $item->addAttribute('Max', $dev->getMax());
                     }
-                    if ( defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "" ) {
+                    if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "") {
                         $item->addAttribute('Event', $dev->getEvent());
                     }
                 }
@@ -438,7 +457,7 @@ class XML
                     if ($dev->getMin() !== null) {
                         $item->addAttribute('Min', $dev->getMin());
                     }
-                    if ( defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "" ) {
+                    if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "") {
                         $item->addAttribute('Event', $dev->getEvent());
                     }
                 }
@@ -456,7 +475,7 @@ class XML
                     if ($dev->getMax() !== null) {
                         $item->addAttribute('Max', $dev->getMax());
                     }
-                    if ( defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "") {
+                    if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "") {
                         $item->addAttribute('Event', $dev->getEvent());
                     }
                 }
@@ -471,7 +490,7 @@ class XML
                     if ($dev->getMax() !== null) {
                         $item->addAttribute('Max', $dev->getMax());
                     }
-                    if ( defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "") {
+                    if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "") {
                         $item->addAttribute('Event', $dev->getEvent());
                     }
                 }
@@ -486,28 +505,12 @@ class XML
                     if ($dev->getMax() !== null) {
                         $item->addAttribute('Max', $dev->getMax());
                     }
-                    if ( defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "") {
+                    if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "") {
                         $item->addAttribute('Event', $dev->getEvent());
                     }
                 }
             }
         }
-
-        if (PSI_HDDTEMP) {
-            $hddtemp = new HDDTemp();
-            $hddtemp_data = $hddtemp->getMBInfo();
-            foreach ($hddtemp_data->getMbTemp() as $dev) {
-                if ($temp == null) {
-                    $temp = $mbinfo->addChild('Temperature');
-                }
-                $item = $temp->addChild('Item');
-                $item->addAttribute('Label', $dev->getName());
-                $item->addAttribute('Value', $dev->getValue());
-                if ($dev->getMax() !== null) {
-                    $item->addAttribute('Max', $dev->getMax());
-                }
-            }
-        }
     }
 
     /**
@@ -518,7 +521,7 @@ class XML
     private function _buildUpsinfo()
     {
         $upsinfo = $this->_xml->addChild('UPSInfo');
-        if ( defined('PSI_UPS_APCUPSD_CGI_ENABLE') && PSI_UPS_APCUPSD_CGI_ENABLE) {
+        if (defined('PSI_UPS_APCUPSD_CGI_ENABLE') && PSI_UPS_APCUPSD_CGI_ENABLE) {
             $upsinfo->addAttribute('ApcupsdCgiLinks', true);
         }
         if (sizeof(unserialize(PSI_UPSINFO))>0) {
@@ -582,10 +585,18 @@ class XML
     private function _buildXml()
     {
         if (!$this->_plugin_request || $this->_complete_request) {
+            if (version_compare("5.2", PHP_VERSION, ">")) {
+                $this->_errors->addError("ERROR", "PHP 5.2 or greater is required, some things may not work correctly");
+            }
             if ($this->_sys === null) {
                 if (PSI_DEBUG === true) {
+                    // unstable version check
+                    if (!is_numeric(substr(PSI_VERSION, -1))) {
+                        $this->_errors->addError("WARN", "This is an unstable version of phpSysInfo, some things may not work correctly");
+                    }
+
                     // Safe mode check
-                    $safe_mode = @ini_get("safe_mode") ? TRUE : FALSE;
+                    $safe_mode = @ini_get("safe_mode") ? true : false;
                     if ($safe_mode) {
                         $this->_errors->addError("WARN", "PhpSysInfo requires to set off 'safe_mode' in 'php.ini'");
                     }
@@ -679,7 +690,7 @@ class XML
         $options = $this->_xml->addChild('Options');
         $options->addAttribute('tempFormat', defined('PSI_TEMP_FORMAT') ? strtolower(PSI_TEMP_FORMAT) : 'c');
         $options->addAttribute('byteFormat', defined('PSI_BYTE_FORMAT') ? strtolower(PSI_BYTE_FORMAT) : 'auto_binary');
-        if ( defined('PSI_REFRESH') ) {
+        if (defined('PSI_REFRESH')) {
             if (PSI_REFRESH === false) {
                 $options->addAttribute('refresh', 0);
             } elseif (PSI_REFRESH === true) {
@@ -690,19 +701,15 @@ class XML
         } else {
             $options->addAttribute('refresh', 60000);
         }
-        if ( defined('PSI_FS_USAGE_THRESHOLD') ) {
+        if (defined('PSI_FS_USAGE_THRESHOLD')) {
             if (PSI_FS_USAGE_THRESHOLD === true) {
                 $options->addAttribute('threshold', 1);
-            } elseif ((PSI_FS_USAGE_THRESHOLD !== false) && (PSI_FS_USAGE_THRESHOLD >= 1) && (PSI_FS_USAGE_THRESHOLD <= 99) ) {
+            } elseif ((PSI_FS_USAGE_THRESHOLD !== false) && (PSI_FS_USAGE_THRESHOLD >= 1) && (PSI_FS_USAGE_THRESHOLD <= 99)) {
                 $options->addAttribute('threshold', PSI_FS_USAGE_THRESHOLD);
             }
         } else {
             $options->addAttribute('threshold', 90);
         }
-        $options->addAttribute('showPickListTemplate', defined('PSI_SHOW_PICKLIST_TEMPLATE') ? (PSI_SHOW_PICKLIST_TEMPLATE ? 'true' : 'false') : 'false');
-        $options->addAttribute('showPickListLang', defined('PSI_SHOW_PICKLIST_LANG') ? (PSI_SHOW_PICKLIST_LANG ? 'true' : 'false') : 'false');
-        $options->addAttribute('showCPUListExpanded', defined('PSI_SHOW_CPULIST_EXPANDED') ? (PSI_SHOW_CPULIST_EXPANDED ? 'true' : 'false') : 'true');
-        $options->addAttribute('showCPUInfoExpanded', defined('PSI_SHOW_CPUINFO_EXPANDED') ? (PSI_SHOW_CPUINFO_EXPANDED ? 'true' : 'false') : 'false');
         if (count($this->_plugins) > 0) {
             if ($this->_plugin_request) {
                 $plug = $this->_xml->addChild('UsedPlugins');
@@ -712,11 +719,13 @@ class XML
                 foreach ($this->_plugins as $plugin) {
                     $plug->addChild('Plugin')->addAttribute('name', $plugin);
                 }
+/*
             } else {
                 $plug = $this->_xml->addChild('UnusedPlugins');
                 foreach ($this->_plugins as $plugin) {
                     $plug->addChild('Plugin')->addAttribute('name', $plugin);
                 }
+*/
             }
         }
     }
