@@ -1,6 +1,6 @@
 /* 
 Copyright: Paul Hanlon
-
+version 2009-06-22+statefix+spanfix+altfix
 Released under the MIT/BSD licence which means you can do anything you want 
 with it, as long as you keep this copyright notice on the page 
 */
@@ -8,11 +8,11 @@ with it, as long as you keep this copyright notice on the page
   jq.fn.jqTreeTable=function(map, options){
     var opts = jq.extend({openImg:"",shutImg:"",leafImg:"",lastOpenImg:"",lastShutImg:"",lastLeafImg:"",vertLineImg:"",blankImg:"",collapse:false,column:0,striped:false,highlight:false,state:true},options),
     mapa=[],mapb=[],tid=this.attr("id"),collarr=[],
-	  stripe=function(){
+	stripe=function(){
       if(opts.striped){
-  		  $("#"+tid+" tr:not(.collapsed)").filter(":even").addClass("even").removeClass("odd").end().filter(":odd").removeClass("even").addClass("odd");
+  	    $("#"+tid+" tr:not(.collapsed)").filter(":even").addClass("even").removeClass("odd").end().filter(":odd").removeClass("even").addClass("odd");
       }
-	  },
+	},
     buildText = function(parno, preStr){//Recursively build up the text for the images that make it work
       var mp=mapa[parno], ro=0, pre="", pref, img;
       for (var y=0,yl=mp.length;y<yl;y++){
@@ -20,12 +20,12 @@ with it, as long as you keep this copyright notice on the page
         if (mapa[ro]){//It's a parent as well. Build it's string and move on to it's children
           pre=(y==yl-1)? opts.blankImg: opts.vertLineImg;
           img=(y==yl-1)? opts.lastOpenImg: opts.openImg;
-          mapb[ro-1] = preStr + '<img src="'+img+'" class="parimg" id="'+tid+ro+'">';
-          pref = preStr + '<img src="'+pre+'" class="preimg">';
+          mapb[ro-1] = preStr + '<span class="treeimg"><img src="'+img+'" alt="" class="parimg" id="'+tid+ro+'"></span>';
+          pref = preStr + '<span class="treeimg"><img src="'+pre+'" alt="" class="preimg"></span>';
           arguments.callee(ro, pref);
         }else{//it's a child
           img = (y==yl-1)? opts.lastLeafImg: opts.leafImg;//It's the last child, It's child will have a blank field behind it
-          mapb[ro-1] = preStr + '<img src="'+img+'" class="ttimage" id="'+tid+ro+'">';
+          mapb[ro-1] = preStr + '<span class="treeimg"><img src="'+img+'" alt="" class="ttimage" id="'+tid+ro+'"></span>';
         }
       }
     },
@@ -72,7 +72,15 @@ with it, as long as you keep this copyright notice on the page
       for(i=0; i<l;i++) o[a[i]] = a[i];
         for(i in o) r.push(o[i]);
           return r;
-	};	
+	};
+
+	var imgtmp = new Image(); //path normalize for ie6
+	imgtmp.src = opts.lastOpenImg;
+	opts.lastOpenImg = imgtmp.src;
+	
+	imgtmp.src = opts.lastShutImg;
+	opts.lastShutImg = imgtmp.src;
+	
 	for (var x=0,xl=map.length; x<xl;x++){//From map of parents, get map of kids
       num = map[x];
       if (!mapa[num]){
