@@ -14,12 +14,12 @@ function renderPlugin_ipmiinfo(data) {
 
     if (data['Plugins']['Plugin_ipmiinfo'] !== undefined) { 
         var data_ipmiinfo = [];
-        var valuelist = {Temperatures:"Temperatures [C]", Voltages:"Voltages [V]", Fans:"Fans [RPM]", Powers:"Powers [W]", Currents:"Currents [A]", Misc:"Misc [0/1]"};
+        var valuelist = {Temperatures:3, Voltages:4, Fans:5, Powers:8, Currents:7, Misc:6};
         for (var ipmiinfo_value in valuelist) {
             if (data['Plugins']['Plugin_ipmiinfo'][ipmiinfo_value] !== undefined) { 
                 var datas = items(data['Plugins']['Plugin_ipmiinfo'][ipmiinfo_value]["Item"]);
                 if (datas.length > 0) {
-                    data_ipmiinfo.push({Label:valuelist[ipmiinfo_value]});
+                    data_ipmiinfo.push({Label:genlang(valuelist[ipmiinfo_value], false ,'ipmiinfo')});
                     data_ipmiinfo.push_attrs(datas);
                 }
             }
