@@ -16,7 +16,7 @@ function renderPlugin_updatenotifier(data) {
         $('#updatenotifier').render(data['Plugins']['Plugin_UpdateNotifier']["UpdateNotifier"], directives);
         if ((data['Plugins']['Plugin_UpdateNotifier']["UpdateNotifier"]["packages"] == 0) &&
             (data['Plugins']['Plugin_UpdateNotifier']["UpdateNotifier"]["security"] == 0) ) {
-            $("#updatenotifier-info").html("<strong>No updates available</strong>");
+            $("#updatenotifier-info").html("<strong>"+genlang(5, false, 'updatenotifier')+"</strong>");
         }
         $('#block_updatenotifier').show();
     } else {
